@@ -1,39 +1,29 @@
 #!/usr/bin/env python
 # vim: set expandtab:
 """
-.. module:: config
-   :synopsis: Parse Asterisk configuration files.
+Parse Asterisk configuration files.
 
 This module provides parsing functionality for asterisk config files.
 
-Example
-----------
-
-.. code-block:: python
-
    import asterisk.config
    import sys
-   
+
    # load and parse the config file
    try:
       config = asterisk.config.Config('/etc/asterisk/extensions.conf')
-   except asterisk.config.ParseError as e:
-      print "Parse Error line: %s: %s" % (e.line, e.strerror)
+   except asterisk.config.ParseError, (line, reason):
+      print "Parse Error line: %s: %s" % (line, reason)
       sys.exit(1)
-   except IOError as e:
-      print "Error opening file: %s" % e.strerror
+   except IOError, reason:
+      print "Error opening file: %s" % reason
       sys.exit(1)
-   
+
    # print our parsed output
    for category in config.categories:
       print '[%s]' % category.name   # print the current category
 
       for item in category.items:
          print '   %s = %s' % (item.name, item.value)
-
-
-Specification
--------------
 """
 
 import sys
